#
# spec file for package python-netmiko
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-netmiko
Version:        2.3.3
Release:        bp156.3.2
Summary:        Multi-vendor library to simplify Paramiko SSH connections to network devices
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/ktbyers/netmiko
Source:         https://files.pythonhosted.org/packages/source/n/netmiko/netmiko-%{version}.tar.gz
Patch0:         netmiko-testing-textfsm-installed-as-module.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python2-enum34
BuildRequires:  python2-ipaddress
Requires:       python-PyYAML
Requires:       python-paramiko >= 2.4.1
Requires:       python-pyserial
Requires:       python-scp >= 0.10.0
Requires:       python-textfsm
BuildArch:      noarch
%ifpython2
Requires:       python-enum34
Requires:       python-ipaddress
%endif
# SECTION test requirements
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module paramiko >= 2.0.0}
BuildRequires:  %{python_module pyserial}
BuildRequires:  %{python_module scp >= 0.10.0}
BuildRequires:  %{python_module textfsm}
# /SECTION
%python_subpackages

%description
Multi-vendor library to simplify Paramiko SSH connections to network devices.

%prep
%setup -q -n netmiko-%{version}
%patch0 -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# NOTE: for testing, we have to manually run it against a given device.
#
# See https://github.com/ktbyers/netmiko/blob/develop/TESTING.md
#
# Unfortunately, we can't do that during build as those doesn't appeared
# to be unit tests.

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/*

%changelog
* Sun Jun  7 2020 Max Lin <mlin@suse.com>
- Fix testing fail with textfsm >= 1.0.0
  * Add netmiko-testing-textfsm-installed-as-module.patch
* Fri Mar  8 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.3
  * Add OneAccess OneOS Support
  * Use Python Black
  * Use environment markers for Poetry support
- Update to version 2.3.2
  * Removing obsolete development status
  * telnet return and return adjustments
  * fixed telnet not position
  * Add oneaccess SSH
  * Update tests for Oneaccss OneOS telnet + ssh;
  * Update Oneaccess OneOS telnet method
  * Add pattern for check_config_mode for cisco_ios and cisco_nxos
  * Ruckus FastIron/ICX telnet echo fix
  * Adding support for file transfer for different version of ios-xr
  * OneOS OneAccess set terminal width
  * Fixes #1028 incorrect parse ls output in error case
  * Allow support for Cisco WLC/AireOS grep include command
  * Updating to support kbytes for IOS-XR
  * Update IP in example code
  * Netscaler fix strip_prompt join.
  * Modified base_connection to check last 3 buffer reads for saved
    prompt.
  * adding blanket juniper statement to snmp auto detect
  * Update test suite to use isolated Arista vEOS
  * Fix ubiquity edge enable issue
  * Fix Python 3 serial driver issue.
  * Add QFabric and Brocade-Extreme NetIron and SLX Support in
    SSH Autodetect.
  * Fix commit issue on huawei
  * Fix Pala Alto not disconnecting gracefully
  * Add ubiquiti_edgeswitch to autodetect
  * Improve error message for WLC failure on initial 'login as'
    authentication.
* Wed Oct 10 2018 mardnh@gmx.de
- Update to version 2.3.0
  * Add Dell DNOS6 support
  * Add RAD ETX support
  * Add IP Infusion OcNOS support
  * Add Paramiko pkey, auth_timeout, and passphrase support.
  * Add support for unicode banners
  * Gracefully cleanup session on failures during session_preparation()
  * Bug fixes
* Thu Jul 19 2018 mardnh@gmx.de
- Update to version 2.2.2
  * Add Dell EMC Isilon Support
  * Add Citrix NetScaler Support
  * Add Dell OS10 Support
  * Add Apresia Systems AEOS Support
  * Add fast_cli mode to Netmiko to improve performance
  * Add support for a session_log
* Mon Jun 25 2018 gyee@suse.com
- Correct package name for python-PyYAML (case-sensitive)
* Thu Jun 21 2018 tchvatal@suse.com
- Use %%license not %%doc macro
* Wed Jun 20 2018 gyee@suse.com
- Remove devel as it is not needed.
* Wed Jun 20 2018 gyee@suse.com
- Remove pytest suggestion.
* Wed Jun 20 2018 gyee@suse.com
- Disable testing during build as those aren't unit tests. See
  See https://github.com/ktbyers/netmiko/blob/develop/TESTING.md
* Tue Jun 19 2018 gyee@suse.com
- Create python-netmiko package.
